@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdevent_line.cpp,v 1.54.2.4 2010/02/18 01:14:17 cvs Exp $
+//      $Id: rdevent_line.cpp,v 1.60.2.4.2.2 2014/06/24 18:27:04 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,6 +24,7 @@
 
 #include <rdconf.h>
 #include <rdcart.h>
+#include <rdevent.h>
 #include <rdevent_line.h>
 #include <schedcartlist.h>
 #include <rddb.h>
@@ -47,14 +48,8 @@ QString RDEventLine::name() const
 void RDEventLine::setName(const QString &name)
 {
   event_name=name;
-  event_preimport_log->
-      setLogName(QString().sprintf("%s_PRE",(const char *)
-				   RDEscapeStringSQLColumn(event_name)).
-		 replace(' ',"_"));
-  event_postimport_log->
-    setLogName(QString().sprintf("%s_POST",(const char *)
-				 RDEscapeStringSQLColumn(event_name)).
-	       replace(' ',"_"));
+  event_preimport_log->setLogName(RDEvent::preimportTableName(event_name));
+  event_postimport_log->setLogName(RDEvent::postimportTableName(event_name));
 }
 
 
@@ -453,7 +448,6 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
   RDSqlQuery *q;
   RDSqlQuery *q1;
   QTime time=event_start_time;
-  QTime end_time=event_start_time.addMSecs(event_length);
   QTime fill_start_time;
   int count=0;
   logname.replace(" ","_");
@@ -509,7 +503,7 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
       sql=QString().sprintf("insert into `%s_LOG` set ID=%d,COUNT=%d,TYPE=%d,\
                              SOURCE=%d,START_TIME=%d,GRACE_TIME=%d,\
                              CART_NUMBER=%u,TIME_TYPE=%d,POST_POINT=\"%s\",\
-                             TRANS_TYPE=%d,COMMENT=\"%s\"",
+                             TRANS_TYPE=%d,COMMENT=\"%s\",EVENT_LENGTH=%d",
 			    (const char *)logname,count,count,
 			    logline->type(),
 			    RDLogLine::Template,
@@ -519,7 +513,8 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 			    (const char *)RDYesNo(post_point),
 			    logline->transType(),
 			    (const char *)
-			    RDEscapeString(logline->markerComment()));
+			    RDEscapeString(logline->markerComment()),
+			    event_length);
       q=new RDSqlQuery(sql);
       delete q;
       count++;
@@ -543,7 +538,6 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
   // Import Links
   //
   if(event_import_source==RDEventLine::Traffic || event_import_source==RDEventLine::Music) {
-//  if(event_import_source!=RDEventLine::None) {
     switch(event_import_source) {
 	case RDEventLine::Traffic:
 	  link_type=RDLogLine::TrafficLink;
@@ -563,7 +557,7 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
                            TIME_TYPE=%d,POST_POINT=\"%s\",TRANS_TYPE=%d,\
                            LINK_EVENT_NAME=\"%s\",LINK_START_TIME=%d,\
                            LINK_LENGTH=%d,LINK_ID=%d,LINK_START_SLOP=%d,\
-                           LINK_END_SLOP=%d",
+                           LINK_END_SLOP=%d,EVENT_LENGTH=%d",
 			  (const char *)logname,count,count,
 			  link_type,RDLogLine::Template,
 			  QTime().msecsTo(time),
@@ -572,12 +566,12 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 			  (const char *)RDYesNo(post_point),
 			  trans_type,
 			  (const char *)RDEscapeString(event_name),
-//			  (const char *)event_start_time.toString("hh:mm:ss"),
 			  QTime().msecsTo(event_start_time),
 			  event_start_time.msecsTo(end_start_time),
 			  link_id,
 			  event_start_slop,
-			  event_end_slop);
+			  event_end_slop,
+			  event_length);
     q=new RDSqlQuery(sql);
     delete q;
     count++;
@@ -790,22 +784,31 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 // end of deconflicting rules
       
       int schedpos = rand()%schedCL->getNumberOfItems();
-      sql=QString().sprintf("insert into %s_LOG set ID=%d,COUNT=%d,TYPE=%d,\
-				  SOURCE=%d,START_TIME=%d,GRACE_TIME=-1, \
-				  CART_NUMBER=%u,TIME_TYPE=%d,POST_POINT=\"%s\", \
-				  TRANS_TYPE=%d,EXT_START_TIME=%d",
+      sql=QString().sprintf("insert into `%s_LOG` set ID=%d,COUNT=%d,TYPE=%d,\
+			     SOURCE=%d,START_TIME=%d,GRACE_TIME=%d, \
+			     CART_NUMBER=%u,TIME_TYPE=%d,POST_POINT=\"%s\", \
+			     TRANS_TYPE=%d,EXT_START_TIME=\"%s\",\
+                             EVENT_LENGTH=%d",
 			    (const char *)logname,count,count,
 			    RDLogLine::Cart,source,
 			    QTime().msecsTo(time),
+			    grace_time,
 			    schedCL->getItemCartnumber(schedpos),
 			    time_type,
 			    (const char *)RDYesNo(post_point),
 			    trans_type,
-			    QTime().msecsTo(time));
+			    (const char *)time.toString("hh:mm:ss"),
+			    event_length);
       q=new RDSqlQuery(sql);
       delete q;
-      
-      sql=QString().sprintf("insert into %s_STACK set SCHED_STACK_ID=%u,CART=%u,ARTIST=\"%s\",SCHED_CODES=\"%s\"",(const char*)svcname_rp,
+
+
+
+      count++;
+
+
+
+      sql=QString().sprintf("insert into `%s_STACK` set SCHED_STACK_ID=%u,CART=%u,ARTIST=\"%s\",SCHED_CODES=\"%s\"",(const char*)svcname_rp,
 			    stackid,schedCL->getItemCartnumber(schedpos),
 			    (const char *)RDEscapeString(schedCL->getItemArtist(schedpos)),(const char *)schedCL->getItemSchedCodes(schedpos));
       q=new RDSqlQuery(sql);
@@ -827,7 +830,7 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
       sql=QString().sprintf("insert into `%s_LOG` set ID=%d,COUNT=%d,TYPE=%d,\
                              SOURCE=%d,START_TIME=%d,GRACE_TIME=%d,\
                              CART_NUMBER=%u,TIME_TYPE=%d,POST_POINT=\"%s\",\
-                             TRANS_TYPE=%d,COMMENT=\"%s\"",
+                             TRANS_TYPE=%d,COMMENT=\"%s\",EVENT_LENGTH=%d",
 			    (const char *)logname,count,count,
 			    logline->type(),
 			    RDLogLine::Template,
@@ -837,7 +840,8 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 			    (const char *)RDYesNo(post_point),
 			    logline->transType(),
 			    (const char *)
-			    RDEscapeString(logline->markerComment()));
+			    RDEscapeString(logline->markerComment()),
+			    event_length);
       q=new RDSqlQuery(sql);
       delete q;
       count++;
@@ -867,16 +871,17 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
   //
   RDLogLine::Source event_src=RDLogLine::Manual;
   switch(event_import_source) {
-      case RDEventLine::Music:
-	event_src=RDLogLine::Music;
-	break;
+  case RDEventLine::Music:
+    event_src=RDLogLine::Music;
+    break;
 
-      case RDEventLine::Traffic:
-	event_src=RDLogLine::Traffic;
-	break;
+  case RDEventLine::Traffic:
+    event_src=RDLogLine::Traffic;
+    break;
 
-      case RDEventLine::None:
-	break;
+  case RDEventLine::Scheduler:
+  case RDEventLine::None:
+    break;
   }
   RDLogLine::TimeType time_type=link_logline->timeType();
   RDLogLine::TransType trans_type=link_logline->transType();
@@ -932,6 +937,7 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
 	  logline->setType(RDLogLine::TrafficLink);
 	  logline->setSource(event_src);
 	  logline->setTransType(trans_type);
+	  logline->setEventLength(event_length);
 	  logline->setLinkEventName(event_nested_event);
 	  logline->setLinkStartTime(link_logline->linkStartTime());
 	  logline->setLinkLength(link_logline->linkLength());
@@ -950,6 +956,7 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
 	logline->setSource(event_src);
 	logline->setTransType(RDLogLine::Segue);
 	logline->setMarkerComment(q->value(11).toString());
+	logline->setEventLength(event_length);
 	logline->setLinkEventName(event_name);
 	logline->setLinkStartTime(link_logline->linkStartTime());
 	logline->setLinkLength(link_logline->linkLength());
@@ -969,6 +976,7 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
 	logline->setSource(event_src);
 	logline->setTransType(RDLogLine::Segue);
 	logline->setMarkerComment(q->value(11).toString());
+        logline->setEventLength(event_length);
 	logline->setLinkEventName(event_name);
 	logline->setLinkStartTime(link_logline->linkStartTime());
 	logline->setLinkLength(link_logline->linkLength());
@@ -986,6 +994,7 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
 	  logline->setType(RDLogLine::TrafficLink);
 	  logline->setSource(event_src);
 	  logline->setTransType(trans_type);
+	  logline->setEventLength(event_length);
 	  logline->setLinkEventName(event_nested_event);
 	  logline->setLinkStartTime(link_logline->linkStartTime());
 	  logline->setLinkLength(link_logline->linkLength());
@@ -1012,6 +1021,7 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
     logline->setExtEventId(q->value(4).toString());
     logline->setExtAnncType(q->value(5).toString());
     logline->setExtCartName(q->value(6).toString());
+    logline->setEventLength(event_length);
     logline->setLinkEventName(event_name);
     logline->setLinkStartTime(link_logline->linkStartTime());
     logline->setLinkLength(link_logline->linkLength());
@@ -1089,6 +1099,7 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
 	  logline->setGraceTime(grace_time);
 	  logline->setCartNumber(q->value(0).toUInt());
 	  logline->setTimeType(time_type);
+	  logline->setEventLength(event_length);
 	  logline->setLinkEventName(event_name);
 	  logline->setLinkStartTime(link_logline->linkStartTime());
 	  logline->setLinkLength(link_logline->linkLength());
