@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdripc.cpp,v 1.30 2008-09-30 18:19:40 fredg Exp $
+//      $Id: rdripc.cpp,v 1.36.6.2 2013/03/09 00:21:11 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,8 +20,11 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qobject.h>
 #include <ctype.h>
+
+#include <qobject.h>
+#include <qapplication.h>
+
 #include <rddb.h>
 #include <rdripc.h>
 
@@ -30,6 +33,7 @@ RDRipc::RDRipc(QString stationname,QObject *parent,const char *name)
   : QObject(parent,name)
 {
   ripc_stationname=stationname;
+  ripc_onair_flag=false;
   ripc_ignore_mask=false;
   debug=false;
   argnum=0;
@@ -65,6 +69,12 @@ QString RDRipc::station() const
 }
 
 
+bool RDRipc::onairFlag() const
+{
+  return ripc_onair_flag;
+}
+
+
 void RDRipc::setUser(QString user)
 {
   SendCommand(QString().sprintf("SU %s!",(const char *)user));
@@ -136,11 +146,21 @@ void RDRipc::sendRml(RDMacro *macro)
 {
   char buffer[RD_RML_MAX_LENGTH];
   char cmd[RD_RML_MAX_LENGTH+4];
+  /*
   int echo=0;
 
   if(macro->echoRequested()) {
     echo=1;
   }
+  */
+  Q_UINT16 port=RD_RML_NOECHO_PORT;
+
+  if(macro->echoRequested()) {
+    port=RD_RML_ECHO_PORT;
+  }
+  if(macro->port()>0) {
+    port=macro->port();
+  }
   macro->generateString(buffer,RD_RML_MAX_LENGTH-1);
   QString rmlline(buffer);
   QString sql=QString().sprintf("select NAME,VARVALUE from HOSTVARS \
@@ -154,12 +174,12 @@ void RDRipc::sendRml(RDMacro *macro)
   switch(macro->role()) {
       case RDMacro::Cmd:
 	sprintf(cmd,"MS %s %d %s",(const char *)macro->address().toString(),
-		echo,(const char *)rmlline);
+		port,(const char *)rmlline);
 	break;
 	
       case RDMacro::Reply:
 	sprintf(cmd,"ME %s %d %s",(const char *)macro->address().toString(),
-		echo,(const char *)rmlline);
+		port,(const char *)rmlline);
 	break;
 
       default:
@@ -366,29 +386,33 @@ void RDRipc::DispatchCommand()
   }
 
   if(!strcmp(args[0],"GC")) {   // GPI Cart Changed
-    if(argnum<4) {
+    if(argnum<5) {
       return;
     }
     int matrix;
     int line;
-    unsigned cartnum; 
+    unsigned off_cartnum; 
+    unsigned on_cartnum; 
     sscanf(args[1],"%d",&matrix);
     sscanf(args[2],"%d",&line);
-    sscanf(args[3],"%d",&cartnum);
-    emit gpiCartChanged(matrix,line,cartnum);
+    sscanf(args[3],"%d",&off_cartnum);
+    sscanf(args[4],"%d",&on_cartnum);
+    emit gpiCartChanged(matrix,line,off_cartnum,on_cartnum);
   }
 
   if(!strcmp(args[0],"GD")) {   // GPO Cart Changed
-    if(argnum<4) {
+    if(argnum<5) {
       return;
     }
     int matrix;
     int line;
-    unsigned cartnum; 
+    unsigned off_cartnum; 
+    unsigned on_cartnum; 
     sscanf(args[1],"%d",&matrix);
     sscanf(args[2],"%d",&line);
-    sscanf(args[3],"%d",&cartnum);
-    emit gpoCartChanged(matrix,line,cartnum);
+    sscanf(args[3],"%d",&off_cartnum);
+    sscanf(args[4],"%d",&on_cartnum);
+    emit gpoCartChanged(matrix,line,off_cartnum,on_cartnum);
   }
 
   if(!strcmp(args[0],"TA")) {   // On Air Flag Changed
@@ -397,4 +421,12 @@ void RDRipc::DispatchCommand()
     }
     emit onairFlagChanged(args[1][0]=='1');
   }
+
+  if(!strcmp(args[0],"TA")) {   // On Air Flag Changed
+    if(argnum!=2) {
+      return;
+    }
+    ripc_onair_flag=args[1][0]=='1';
+    emit onairFlagChanged(ripc_onair_flag);
+  }
 }
