@@ -30,6 +30,7 @@
 #include <qdatetime.h>
 #include <qstringlist.h>
 
+#include <rdescape_string.h>
 #include <rduser.h>
 #include <rddb.h>
 #include <rdconf.h>
@@ -686,14 +687,11 @@ long int RDAuthenticateLogin(const QString &username,const QString &passwd,
   timeval=time(&timeval);
   srandom(timeval);
   long int session=random();
-  QString sql=QString().sprintf("insert into WEB_CONNECTIONS set \
-                                 SESSION_ID=%ld,\
-                                 LOGIN_NAME=\"%s\",\
-                                 IP_ADDRESS=\"%s\",\
-                                 TIME_STAMP=now()",
-				session,
-				(const char *)username,
-				(const char *)addr.toString());
+  QString sql=QString("insert into WEB_CONNECTIONS set ")+
+    QString().sprintf("SESSION_ID=%ld,",session)+
+    "LOGIN_NAME=\""+RDEscapeString(username)+"\","+
+    "IP_ADDRESS=\""+addr.toString()+"\","+
+    "TIME_STAMP=now()";
   RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
 
@@ -703,25 +701,25 @@ long int RDAuthenticateLogin(const QString &username,const QString &passwd,
 
 QString RDAuthenticateSession(long int session_id,const QHostAddress &addr)
 {
+  QString sql;
+  RDSqlQuery *q;
+
   //
   // Expire Stale Sessions
   //
   QDateTime current_datetime=
     QDateTime(QDate::currentDate(),QTime::currentTime());
-  QString sql=QString().sprintf("delete from WEB_CONNECTIONS \
-                                 where TIME_STAMP<\"%s\"",
-				(const char *)current_datetime.
-				addSecs(-RD_WEB_SESSION_TIMEOUT).
-				toString("yyyy-MM-dd hh:mm:ss"));
-  RDSqlQuery *q=new RDSqlQuery(sql);
+  sql=QString("delete from WEB_CONNECTIONS where ")+
+    "TIME_STAMP<\""+current_datetime.addSecs(-RD_WEB_SESSION_TIMEOUT).
+    toString("yyyy-MM-dd hh:mm:ss")+"\"";
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
   // Check for Session
   //
-  sql=QString().sprintf("select LOGIN_NAME,IP_ADDRESS from WEB_CONNECTIONS \
-                         where SESSION_ID=%ld",
-			session_id);
+  sql=QString("select LOGIN_NAME,IP_ADDRESS from WEB_CONNECTIONS where ")+
+    QString().sprintf("SESSION_ID=%ld",session_id);
   q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
@@ -737,11 +735,9 @@ QString RDAuthenticateSession(long int session_id,const QHostAddress &addr)
   //
   // Update Session
   //
-  sql=QString().sprintf("update WEB_CONNECTIONS set TIME_STAMP=\"%s\" \
-                         where SESSION_ID=%ld",
-			(const char *)current_datetime.
-			toString("yyyy-MM-dd hh:mm:dd"),
-			session_id);
+  sql=QString("update WEB_CONNECTIONS set ")+
+    "TIME_STAMP=\""+current_datetime.toString("yyyy-MM-dd hh:mm:dd")+"\" "+
+    QString().sprintf("where SESSION_ID=%ld",session_id);
   q=new RDSqlQuery(sql);
   delete q;
 
@@ -771,19 +767,6 @@ void RDLogoutSession(long int session_id,const QHostAddress &addr)
 }
 
 
-QString RDEscapeWebString(const QString &str)
-{
-  QString ret=str;
-  ret.replace("&","&amp;");
-  ret.replace("`","&apos;");
-  ret.replace("'","&apos;");
-  ret.replace(">","&gt;");
-  ret.replace("<","&lt;");
-  ret.replace("\"","&quot;");
-  return ret;
-}
-
-
 bool RDParsePost(std::map<QString,QString> *vars)
 {
   std::map<QString,QString> headers;
@@ -800,13 +783,7 @@ bool RDParsePost(std::map<QString,QString> *vars)
   //
   // Initialize Temp Directory Path
   //
-  if(getenv("TMPDIR")!=NULL) {
-    tempdir=getenv("TMPDIR");
-  }
-  else {
-    tempdir="/tmp";
-  }
-  tempdir+="/rivendellXXXXXX";
+  tempdir = RDTempDir() + "/rivendellXXXXXX";
 
   //
   // Get message part separator
@@ -895,53 +872,99 @@ bool RDParsePost(std::map<QString,QString> *vars)
 }
 
 
-QString RDXmlField(const QString &tag,const QString &value)
+QString RDXmlField(const QString &tag,const QString &value,const QString &attrs)
 {
-  return QString("<")+tag+">"+RDXmlEscape(value)+"</"+tag+">\n";
-}
+  QString str="";
 
-
-QString RDXmlField(const QString &tag,const char *value)
-{
-  return RDXmlField(tag,QString(value));
-}
-
-
-QString RDXmlField(const QString &tag,const int value)
-{
-  return QString("<")+tag+">"+QString().sprintf("%d",value)+"</"+tag+">\n";
-}
-
-
-QString RDXmlField(const QString &tag,const unsigned value)
-{
-  return QString("<")+tag+">"+QString().sprintf("%u",value)+"</"+tag+">\n";
-}
-
-
-QString RDXmlField(const QString &tag,const bool value)
-{
-  if(value) {
-    return QString("<")+tag+">true</"+tag+">\n";
+  if(!attrs.isEmpty()) {
+    str=" "+attrs;
   }
-  return QString("<")+tag+">false</"+tag+">\n";
+  return QString("<")+tag+str+">"+RDXmlEscape(value)+"</"+tag+">\n";
 }
 
 
-QString RDXmlField(const QString &tag,const QDateTime &value)
+QString RDXmlField(const QString &tag,const char *value,const QString &attrs)
 {
-  return QString("<")+tag+">"+RDWebDateTime(value)+"</"+tag+">\n";
+  return RDXmlField(tag,QString(value),attrs);
 }
 
 
-QString RDXmlField(const QString &tag,const QTime &value)
+QString RDXmlField(const QString &tag,const int value,const QString &attrs)
 {
-  return QString("<")+tag+">"+value.toString("hh:mm:ss")+"</"+tag+">\n";
+  QString str="";
+
+  if(!attrs.isEmpty()) {
+    str=" "+attrs;
+  }
+  return QString("<")+tag+str+">"+QString().sprintf("%d",value)+"</"+tag+">\n";
+}
+
+
+QString RDXmlField(const QString &tag,const unsigned value,const QString &attrs)
+{
+  QString str="";
+
+  if(!attrs.isEmpty()) {
+    str=" "+attrs;
+  }
+  return QString("<")+tag+str+">"+QString().sprintf("%u",value)+"</"+tag+">\n";
+}
+
+
+QString RDXmlField(const QString &tag,const bool value,const QString &attrs)
+{
+  QString str="";
+
+  if(!attrs.isEmpty()) {
+    str=" "+attrs;
+  }
+  if(value) {
+    return QString("<")+tag+str+">true</"+tag+">\n";
+  }
+  return QString("<")+tag+str+">false</"+tag+">\n";
+}
+
+
+QString RDXmlField(const QString &tag,const QDateTime &value,
+		   const QString &attrs)
+{
+  QString str="";
+
+  if(!attrs.isEmpty()) {
+    str=" "+attrs;
+  }
+  if(value.isValid()) {
+    return QString("<")+tag+str+">"+RDWebDateTime(value)+"</"+tag+">\n";
+  }
+  return RDXmlField(tag);
+}
+
+
+QString RDXmlField(const QString &tag,const QTime &value,const QString &attrs)
+{
+  QString str="";
+
+  if(!attrs.isEmpty()) {
+    str=" "+attrs;
+  }
+  if(value.isValid()&&(!value.isNull())) {
+    return QString("<")+tag+str+">"+value.toString("hh:mm:ss")+"</"+tag+">\n";
+  }
+  return RDXmlField(tag);
+}
+
+
+QString RDXmlField(const QString &tag)
+{
+  return QString("<")+tag+"/>\n";
 }
 
 
 QString RDXmlEscape(const QString &str)
 {
+  /*
+   * Escape a string in accordance with XML-1.0
+   */
   QString ret=str;
   ret.replace("&","&amp;");
   ret.replace("<","&lt;");
@@ -954,6 +977,9 @@ QString RDXmlEscape(const QString &str)
 
 QString RDXmlUnescape(const QString &str)
 {
+  /*
+   * Unescape a string in accordance with XML-1.0
+   */
   QString ret=str;
   ret.replace("&amp;","&");
   ret.replace("&lt;","<");
@@ -964,6 +990,53 @@ QString RDXmlUnescape(const QString &str)
 }
 
 
+QString RDUrlEscape(const QString &str)
+{
+  /*
+   * Escape a string in accordance with RFC 2396 Section 2.4
+   */
+  QString ret=str;
+
+  ret.replace("%","%25");
+  ret.replace(" ","%20");
+  ret.replace("<","%3C");
+  ret.replace(">","%3E");
+  ret.replace("#","%23");
+  ret.replace("\"","%22");
+  ret.replace("{","%7B");
+  ret.replace("}","%7D");
+  ret.replace("|","%7C");
+  ret.replace("\\","%5C");
+  ret.replace("^","%5E");
+  ret.replace("[","%5B");
+  ret.replace("]","%5D");
+  ret.replace("~","%7E");
+
+  return ret;
+}
+
+
+QString RDUrlUnescape(const QString &str)
+{
+  /*
+   * Unescape a string in accordance with RFC 2396 Section 2.4
+   */
+  QString ret="";
+
+  for(unsigned i=0;i<str.length();i++) {
+    if((str.at(i)=="%")&&(i<str.length()-2)) {
+      ret+=QString().sprintf("%c",str.mid(i+1,2).toInt(NULL,16));
+      i+=2;
+    }
+    else {
+      ret+=str.at(i);
+    }
+  }
+
+  return ret;
+}
+
+
 QString RDWebDateTime(const QDateTime &datetime)
 {
   //
