@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_event.h,v 1.20 2007-09-14 14:06:58 fredg Exp $
+//      $Id: edit_event.h,v 1.24.8.1 2013/12/30 20:37:01 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -36,10 +36,12 @@
 #include <qspinbox.h>
 #include <qcombobox.h>
 #include <qbuttongroup.h>
+#include <qtextedit.h>
 
 #include <rdtransportbutton.h>
 
 #include <rduser.h>
+#include <rdemptycart.h>
 #include <rdevent.h>
 #include <rdevent_line.h>
 #include <rdsimpleplayer.h>
@@ -71,14 +73,15 @@ class EditEvent : public QDialog
   void timeToggledData(bool);
   void graceClickedData(int);
   void timeTransitionData(int);
-  void autofillToggledData(bool);
   void autofillWarnToggledData(bool);
   void importClickedData(int);
   void preimportChangedData(int size);
+  void preimportLengthChangedData(int msecs);
   void preimportUpData();
   void preimportDownData();
   void postimportUpData();
   void postimportDownData();
+  void postimportLengthChangedData(int msecs);
   void saveData();
   void saveAsData();
   void svcData();
@@ -87,6 +90,7 @@ class EditEvent : public QDialog
   void cancelData();
 
  protected:
+  void closeEvent(QCloseEvent *e);
   void paintEvent(QPaintEvent *e);
 
  private:
@@ -134,6 +138,7 @@ class EditEvent : public QDialog
   QTimeEdit *event_autofill_slop_edit;
   QCheckBox *event_timescale_box;
   ImportListView *event_preimport_list;
+  QLineEdit *event_preimport_length_edit;
   RDTransportButton *event_preimport_up_button;
   RDTransportButton *event_preimport_down_button;
   QButtonGroup *event_source_group;
@@ -153,6 +158,7 @@ class EditEvent : public QDialog
   QComboBox *event_nestevent_box;
   QLabel *event_nestevent_unit;
   ImportListView *event_postimport_list;
+  QLineEdit *event_postimport_length_edit;
   RDTransportButton *event_postimport_up_button;
   RDTransportButton *event_postimport_down_button;
   QPushButton *event_color_button;
@@ -160,6 +166,8 @@ class EditEvent : public QDialog
   bool event_new_event;
   std::vector<QString> *event_new_events;
   RDSimplePlayer *event_player;
+  QTextEdit *event_remarks_edit;
+  RDEmptyCart *event_empty_cart;
 };
 
 
